@@ -12,7 +12,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::Test::Compile;
 {
-  $Dist::Zilla::Plugin::Test::Compile::VERSION = '1.112400';
+  $Dist::Zilla::Plugin::Test::Compile::VERSION = '1.112820';
 }
 # ABSTRACT: common tests to check syntax of your modules
 
@@ -84,7 +84,7 @@ Dist::Zilla::Plugin::Test::Compile - common tests to check syntax of your module
 
 =head1 VERSION
 
-version 1.112400
+version 1.112820
 
 =head1 SYNOPSIS
 
@@ -108,6 +108,8 @@ This test will find all modules and scripts in your dist, and try to
 compile them one by one. This means it's a bit slower than loading them
 all at once, but it will catch more errors.
 
+We currently only check bin/, script/ and scripts/ for scripts.
+
 =back
 
 This plugin accepts the following options:
@@ -198,8 +200,10 @@ find(
   'lib',
 );
 
-my @scripts;
-if ( -d 'bin' ) {
+sub _find_scripts {
+    my $dir = shift @_;
+
+    my @found_scripts = ();
     find(
       sub {
         return unless -f;
@@ -211,12 +215,18 @@ if ( -d 'bin' ) {
         };
         my $shebang = <$FH>;
         return unless $shebang =~ /^#!.*?\bperl\b\s*$/;
-        push @scripts, $found;
+        push @found_scripts, $found;
       },
-      'bin',
+      $dir,
     );
+
+    return @found_scripts;
 }
 
+my @scripts;
+do { push @scripts, _find_scripts($_) if -d $_ }
+    for qw{ bin script scripts };
+
 my $plan = scalar(@modules) + scalar(@scripts);
 $plan ? (plan tests => $plan) : (plan skip_all => "no tests to run");
 
